@@ -29,13 +29,7 @@ class UserProfile(models.Model):
 
 
 class EmailVerification(models.Model):
-    user = models.ForeignKey(
-        User,
-        related_name="email_verifications",
-        null=True,
-        blank=True,
-        on_delete=models.CASCADE,
-    )
+    user = models.ForeignKey(User, related_name="email_verifications", null=True, blank=True, on_delete=models.CASCADE)
     token = models.CharField(max_length=30)
     email = models.CharField(max_length=200, null=True, default=None, blank=True)
     expiry = models.DateTimeField()
@@ -79,18 +73,11 @@ class School(models.Model):
         self.is_active = False
         self.save()
 
-        # Remove teachers' requests to join this school
-        self.join_request.clear()
-
 
 class TeacherModelManager(models.Manager):
     def factory(self, first_name, last_name, email, password):
         user = User.objects.create_user(
-            username=email,
-            email=email,
-            password=password,
-            first_name=first_name,
-            last_name=last_name,
+            username=email, email=email, password=password, first_name=first_name, last_name=last_name
         )
 
         user_profile = UserProfile.objects.create(user=user)
@@ -104,23 +91,13 @@ class TeacherModelManager(models.Manager):
 
 class Teacher(models.Model):
     user = models.OneToOneField(UserProfile, on_delete=models.CASCADE)
-    new_user = models.OneToOneField(
-        User,
-        related_name="new_teacher",
-        null=True,
-        blank=True,
-        on_delete=models.CASCADE,
-    )
+    new_user = models.OneToOneField(User, related_name="new_teacher", null=True, blank=True, on_delete=models.CASCADE)
     school = models.ForeignKey(School, related_name="teacher_school", null=True, on_delete=models.SET_NULL)
     is_admin = models.BooleanField(default=False)
-    pending_join_request = models.ForeignKey(
-        School,
-        related_name="join_request",
-        null=True,
-        blank=True,
-        on_delete=models.SET_NULL,
+    blocked_time = models.DateTimeField(null=True, blank=True)
+    invited_by = models.ForeignKey(
+        "self", related_name="invited_teachers", null=True, blank=True, on_delete=models.SET_NULL
     )
-    blocked_time = models.DateTimeField(null=True)
 
     objects = TeacherModelManager()
 
@@ -139,6 +116,41 @@ class Teacher(models.Model):
         return f"{self.new_user.first_name} {self.new_user.last_name}"
 
 
+class SchoolTeacherInvitationModelManager(models.Manager):
+    # Filter out inactive invitations by default
+    def get_queryset(self):
+        return super().get_queryset().filter(is_active=True)
+
+
+class SchoolTeacherInvitation(models.Model):
+    token = models.CharField(max_length=32)
+    school = models.ForeignKey(School, related_name="teacher_invitations", null=True, on_delete=models.SET_NULL)
+    from_teacher = models.ForeignKey(Teacher, related_name="school_invitations", null=True, on_delete=models.SET_NULL)
+    invited_teacher_first_name = models.CharField(max_length=150)  # Same as User model
+    invited_teacher_last_name = models.CharField(max_length=150)  # Same as User model
+    invited_teacher_email = models.EmailField()  # Same as User model
+    invited_teacher_is_admin = models.BooleanField(default=False)
+    expiry = models.DateTimeField()
+    creation_time = models.DateTimeField(default=timezone.now, null=True)
+    is_active = models.BooleanField(default=True)
+
+    objects = SchoolTeacherInvitationModelManager()
+
+    @property
+    def is_expired(self):
+        return self.expiry < timezone.now()
+
+    def __str__(self):
+        return f"School teacher invitation for {self.invited_teacher_email} to {self.school.name}"
+
+    def anonymise(self):
+        self.invited_teacher_first_name = uuid4().hex
+        self.invited_teacher_last_name = uuid4().hex
+        self.invited_teacher_email = uuid4().hex
+        self.is_active = False
+        self.save()
+
+
 class ClassModelManager(models.Manager):
     def all_members(self, user):
         members = []
@@ -236,9 +248,7 @@ class StudentModelManager(models.Manager):
         user = User.objects.create_user(username=self.get_random_username(), password=password, first_name=name)
         user_profile = UserProfile.objects.create(user=user)
 
-        return Student.objects.create(
-            class_field=klass, user=user_profile, new_user=user, login_id=login_id
-        )
+        return Student.objects.create(class_field=klass, user=user_profile, new_user=user, login_id=login_id)
 
     def independentStudentFactory(self, name, email, password):
         user = User.objects.create_user(username=email, email=email, password=password, first_name=name)
@@ -253,13 +263,7 @@ class Student(models.Model):
     # hashed uuid used for the unique direct login url
     login_id = models.CharField(max_length=64, null=True)
     user = models.OneToOneField(UserProfile, on_delete=models.CASCADE)
-    new_user = models.OneToOneField(
-        User,
-        related_name="new_student",
-        null=True,
-        blank=True,
-        on_delete=models.CASCADE,
-    )
+    new_user = models.OneToOneField(User, related_name="new_student", null=True, blank=True, on_delete=models.CASCADE)
     pending_class_request = models.ForeignKey(Class, related_name="class_request", null=True, on_delete=models.SET_NULL)
     blocked_time = models.DateTimeField(null=True)
 
